@@ -6,10 +6,10 @@ use warnings;
 use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 use constant DESC => 'Using -w switch';
-use constant EXPL => 'Don\'t use -w, it\'s too eager. use warnings; instead.';
+use constant EXPL => 'Don\'t use -w (or -W), it\'s too eager. use warnings; instead.';
 
 sub supported_parameters { () }
 sub default_severity { $SEVERITY_LOW }
@@ -21,7 +21,7 @@ sub violates {
 	my $shebang = $elem->first_token;
 	return () unless $shebang->isa('PPI::Token::Comment') and $shebang->content =~ m/^#!/;
 	
-	return $self->violation(DESC, EXPL, $elem) if $shebang->content =~ m/\h-[a-zA-Z]*w/;
+	return $self->violation(DESC, EXPL, $elem) if $shebang->content =~ m/\h-[a-zA-Z]*[wW]/;
 	
 	return ();
 }
@@ -36,11 +36,14 @@ switch on the shebang line
 =head1 DESCRIPTION
 
 The C<-w> switch enables warnings globally in a perl program, including for any
-modules that did not explicitly enable or disable any warnings. Some of these
-modules may not be designed to run with warnings enabled, but still work fine.
-Instead, use L<warnings> within your own code only.
+modules that did not explicitly enable or disable any warnings. The C<-W>
+switch enables warnings even for modules that explicitly disabled them. The
+primary issue with this is enabling warnings for code that you did not write.
+Some of these modules may not be designed to run with warnings enabled, but
+still work fine. Instead, use L<warnings> within your own code only.
 
   #!/usr/bin/perl -w # not ok
+  #!/usr/bin/perl -W # not ok
   use warnings;      # ok
 
 =head1 AFFILIATION
@@ -64,4 +67,4 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
-L<Perl::Critic>
+L<Perl::Critic>, L<warnings>
